@@ -2,22 +2,9 @@
  *
  * Copyright (C) 2012 Red Hat, Inc.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Licensed under GPL version 2 or later.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- *
- * Author: David Zeuthen <davidz@redhat.com>
+ * Author: David Zeuthen <zeuthen@gmail.com>
  */
 
 #include "config.h"
@@ -28,7 +15,7 @@
 
 #include <gtk/gtk.h>
 
-#include <udisks/udisks.h>
+#include <libgdu/libgdu.h>
 
 static gboolean have_gtk = FALSE;
 static UDisksClient *udisks_client = NULL;
@@ -81,31 +68,6 @@ static const GOptionEntry opt_entries[] =
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-/* TODO: keep in sync with src/disks/gduutils.c (ideally in shared lib) */
-static void
-_gdu_utils_configure_file_chooser_for_disk_images (GtkFileChooser *file_chooser)
-{
-  GtkFileFilter *filter;
-  const gchar *folder;
-
-  /* Default to the "Documents" folder since that's where we save such images */
-  folder = g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS);
-  if (folder != NULL)
-    gtk_file_chooser_set_current_folder (file_chooser, folder);
-
-  /* TODO: define proper mime-types */
-  filter = gtk_file_filter_new ();
-  gtk_file_filter_set_name (filter, _("All Files"));
-  gtk_file_filter_add_pattern (filter, "*");
-  gtk_file_chooser_add_filter (file_chooser, filter); /* adopts filter */
-  filter = gtk_file_filter_new ();
-  gtk_file_filter_set_name (filter, _("Disk Images (*.img, *.iso)"));
-  gtk_file_filter_add_pattern (filter, "*.img");
-  gtk_file_filter_add_pattern (filter, "*.iso");
-  gtk_file_chooser_add_filter (file_chooser, filter); /* adopts filter */
-  gtk_file_chooser_set_filter (file_chooser, filter);
-}
-
 static GSList *
 do_filechooser (void)
 {
@@ -121,7 +83,7 @@ do_filechooser (void)
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                         _("_Mount"), GTK_RESPONSE_ACCEPT,
                                         NULL);
-  _gdu_utils_configure_file_chooser_for_disk_images (GTK_FILE_CHOOSER (dialog));
+  gdu_utils_configure_file_chooser_for_disk_images (GTK_FILE_CHOOSER (dialog), TRUE);
   gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), FALSE);
 
   /* Add a RO check button that defaults to RO */
