@@ -1,23 +1,10 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
  *
- * Copyright (C) 2008-2011 Red Hat, Inc.
+ * Copyright (C) 2008-2012 Red Hat, Inc.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Licensed under GPL version 2 or later.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- *
- * Author: David Zeuthen <davidz@redhat.com>
+ * Author: David Zeuthen <zeuthen@gmail.com>
  */
 
 #include "config.h"
@@ -27,7 +14,6 @@
 #include "gduapplication.h"
 #include "gduwindow.h"
 #include "gduatasmartdialog.h"
-#include "gduutils.h"
 
 enum
 {
@@ -1309,9 +1295,9 @@ refresh_cb (UDisksDriveAta  *ata,
   error = NULL;
   if (!udisks_drive_ata_call_smart_update_finish (ata, res, &error))
     {
-      gdu_window_show_error (window,
-                             _("Error refreshing SMART data"),
-                             error);
+      gdu_utils_show_error (GTK_WINDOW (window),
+                            _("Error refreshing SMART data"),
+                            error);
       g_error_free (error);
     }
   g_object_unref (window);
@@ -1341,9 +1327,9 @@ smart_cancel_cb (UDisksDriveAta  *ata,
   error = NULL;
   if (!udisks_drive_ata_call_smart_selftest_abort_finish (ata, res, &error))
     {
-      gdu_window_show_error (window,
-                             _("Error aborting SMART self-test"),
-                             error);
+      gdu_utils_show_error (GTK_WINDOW (window),
+                            _("Error aborting SMART self-test"),
+                            error);
       g_error_free (error);
     }
   g_object_unref (window);
@@ -1360,9 +1346,9 @@ smart_start_cb (UDisksDriveAta  *ata,
   error = NULL;
   if (!udisks_drive_ata_call_smart_selftest_start_finish (ata, res, &error))
     {
-      gdu_window_show_error (window,
-                             _("Error starting SMART self-test"),
-                             error);
+      gdu_utils_show_error (GTK_WINDOW (window),
+                            _("Error starting SMART self-test"),
+                            error);
       g_error_free (error);
     }
   g_object_unref (window);
