@@ -1,23 +1,10 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
  *
- * Copyright (C) 2008-2011 Red Hat, Inc.
+ * Copyright (C) 2008-2012 Red Hat, Inc.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Licensed under GPL version 2 or later.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- *
- * Author: David Zeuthen <davidz@redhat.com>
+ * Author: David Zeuthen <zeuthen@gmail.com>
  */
 
 #include "config.h"
@@ -26,6 +13,7 @@
 #include <gio/gunixfdlist.h>
 #include <gio/gunixinputstream.h>
 
+#include <gmodule.h>
 #include <glib-unix.h>
 #include <sys/ioctl.h>
 #include <linux/fs.h>
@@ -34,7 +22,6 @@
 #include "gduwindow.h"
 #include "gducreatediskimagedialog.h"
 #include "gduvolumegrid.h"
-#include "gduutils.h"
 #include "gducreatefilesystemwidget.h"
 #include "gduestimator.h"
 
@@ -76,6 +63,7 @@ typedef struct
   GtkWidget *copying_progress_label;
 
   GCancellable *cancellable;
+  int fd;
   GInputStream *block_stream;
   GFile *output_file;
   GFileOutputStream *output_file_stream;
@@ -88,8 +76,13 @@ typedef struct
   guint64 buffer_bytes_to_write;
 
   GduEstimator *estimator;
+
+  gulong response_signal_handler_id;
+  gboolean completed;
 } CreateDiskImageData;
 
+/* ---------------------------------------------------------------------------------------------------- */
+
 static CreateDiskImageData *
 create_disk_image_data_ref (CreateDiskImageData *data)
 {
@@ -102,10 +95,16 @@ create_disk_image_data_unref (CreateDiskImageData *data)
 {
   if (g_atomic_int_dec_and_test (&data->ref_count))
     {
+      /* hide the dialog */
       if (data->dialog != NULL)
         {
-          gtk_widget_hide (data->dialog);
-          gtk_widget_destroy (data->dialog);
+          GtkWidget *dialog;
+          if (data->response_signal_handler_id != 0)
+            g_signal_handler_disconnect (data->dialog, data->response_signal_handler_id);
+          dialog = data->dialog;
+          data->dialog = NULL;
+          gtk_widget_hide (dialog);
+          gtk_widget_destroy (dialog);
         }
       g_clear_object (&data->cancellable);
       g_clear_object (&data->output_file_stream);
@@ -137,8 +136,12 @@ create_disk_image_data_unref (CreateDiskImageData *data)
 static void
 create_disk_image_data_complete (CreateDiskImageData *data)
 {
-  g_cancellable_cancel (data->cancellable);
-  gtk_dialog_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_CANCEL);
+  if (!data->completed)
+    {
+      data->completed = TRUE;
+      g_cancellable_cancel (data->cancellable);
+      create_disk_image_data_unref (data);
+    }
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -171,10 +174,12 @@ create_disk_image_populate (CreateDiskImageData *data)
 {
   gchar *device_name;
   gchar *now_string;
-  gchar *s;
+  gchar *proposed_filename = NULL;
   guint n;
   GTimeZone *tz;
   GDateTime *now;
+  const gchar *fstype;
+  const gchar *fslabel;
 
   device_name = udisks_block_dup_preferred_device (data->block);
   if (g_str_has_prefix (device_name, "/dev/"))
@@ -189,21 +194,34 @@ create_disk_image_populate (CreateDiskImageData *data)
   now = g_date_time_new_now (tz);
   now_string = g_date_time_format (now, "%Y-%m-%d %H%M");
 
-  /* Translators: The suggested name for the disk image to create.
-   *              The first %s is a name for the disk (e.g. 'sdb').
-   *              The second %s is today's date and time, e.g. "March 2, 1976 6:25AM".
-   */
-  s = g_strdup_printf (_("Disk Image of %s (%s).img"),
-                       device_name,
-                       now_string);
-  gtk_entry_set_text (GTK_ENTRY (data->destination_name_entry), s);
-  g_free (s);
+  /* If it's an ISO/UDF filesystem, suggest a filename ending in .iso */
+  fstype = udisks_block_get_id_type (data->block);
+  fslabel = udisks_block_get_id_label (data->block);
+  if (g_strcmp0 (fstype, "iso9660") == 0 || g_strcmp0 (fstype, "udf") == 0)
+    {
+      if (fslabel != NULL && strlen (fslabel) > 0)
+        proposed_filename = g_strdup_printf ("%s.iso", fslabel);
+    }
+
+  if (proposed_filename == NULL)
+    {
+      /* Translators: The suggested name for the disk image to create.
+       *              The first %s is a name for the disk (e.g. 'sdb').
+       *              The second %s is today's date and time, e.g. "March 2, 1976 6:25AM".
+       */
+      proposed_filename = g_strdup_printf (_("Disk Image of %s (%s).img"),
+                                           device_name,
+                                           now_string);
+    }
+
+  gtk_entry_set_text (GTK_ENTRY (data->destination_name_entry), proposed_filename);
+  g_free (proposed_filename);
   g_free (device_name);
   g_date_time_unref (now);
   g_time_zone_unref (tz);
   g_free (now_string);
 
-  gdu_utils_configure_file_chooser_for_disk_images (GTK_FILE_CHOOSER (data->destination_name_fcbutton));
+  gdu_utils_configure_file_chooser_for_disk_images (GTK_FILE_CHOOSER (data->destination_name_fcbutton), FALSE);
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -229,8 +247,8 @@ write_cb (GOutputStream  *output_stream,
   if (error != NULL)
     {
       if (!(error->domain == G_IO_ERROR && error->code == G_IO_ERROR_CANCELLED))
-        gdu_window_show_error (data->window,
-                               _("Error writing to backup image"), error);
+        gdu_utils_show_error (GTK_WINDOW (data->dialog),
+                              _("Error writing to image"), error);
       g_error_free (error);
       create_disk_image_data_complete (data);
       goto out;
@@ -304,6 +322,7 @@ write_more (CreateDiskImageData *data)
     }
 }
 
+/* ---------------------------------------------------------------------------------------------------- */
 
 static void
 read_cb (GInputStream  *input_stream,
@@ -323,13 +342,15 @@ read_cb (GInputStream  *input_stream,
                            (guint64) data->total_bytes_read,
                            udisks_block_get_preferred_device (data->block));
       if (!(error->domain == G_IO_ERROR && error->code == G_IO_ERROR_CANCELLED))
-        gdu_window_show_error (data->window, s, error);
+        gdu_utils_show_error (GTK_WINDOW (data->dialog), s, error);
       g_free (s);
       g_error_free (error);
       create_disk_image_data_complete (data);
       goto out;
     }
 
+  /* TODO: handle zero bytes being read */
+
   data->total_bytes_read += bytes_read;
 
   data->buffer_bytes_written = 0;
@@ -368,6 +389,38 @@ copy_more (CreateDiskImageData *data)
 
 /* ---------------------------------------------------------------------------------------------------- */
 
+static void
+start_copying (CreateDiskImageData *data)
+{
+  g_assert (data->fd != 0);
+
+  /* We can't use udisks_block_get_size() because the media may have
+   * changed and udisks may not have noticed. TODO: maybe have a
+   * Block.GetSize() method instead...
+   */
+  if (ioctl (data->fd, BLKGETSIZE64, &data->block_size) != 0)
+    {
+      GError *error = g_error_new (G_IO_ERROR, g_io_error_from_errno (errno), "%s", strerror (errno));
+      gdu_utils_show_error (GTK_WINDOW (data->dialog), _("Error determining size of device"), error);
+      g_error_free (error);
+      create_disk_image_data_complete (data);
+      goto out;
+    }
+
+  /* now that we know the user picked a folder, update file chooser settings */
+  gdu_utils_file_chooser_for_disk_images_update_settings (GTK_FILE_CHOOSER (data->destination_name_fcbutton));
+
+  data->cancellable = g_cancellable_new ();
+  data->buffer = g_new0 (guchar, BUFFER_SIZE);
+  data->estimator = gdu_estimator_new (data->block_size);
+  data->block_stream = g_unix_input_stream_new (data->fd, TRUE);
+
+  /* Alright, time to start copying! */
+  copy_more (data);
+ out:
+  ;
+}
+
 static void
 open_cb (UDisksBlock  *block,
          GAsyncResult *res,
@@ -377,7 +430,6 @@ open_cb (UDisksBlock  *block,
   GError *error;
   GUnixFDList *fd_list = NULL;
   GVariant *fd_index = NULL;
-  int fd;
 
   error = NULL;
   if (!udisks_block_call_open_for_backup_finish (block,
@@ -387,34 +439,15 @@ open_cb (UDisksBlock  *block,
                                                  &error))
     {
       if (!(error->domain == G_IO_ERROR && error->code == G_IO_ERROR_CANCELLED))
-        gdu_window_show_error (data->window, _("Error opening device"), error);
+        gdu_utils_show_error (GTK_WINDOW (data->dialog), _("Error opening device"), error);
       g_error_free (error);
       create_disk_image_data_complete (data);
       goto out;
     }
 
-  fd = g_unix_fd_list_get (fd_list, g_variant_get_handle (fd_index), NULL);
+  data->fd = g_unix_fd_list_get (fd_list, g_variant_get_handle (fd_index), NULL);
 
-  /* We can't use udisks_block_get_size() because the media may have
-   * changed and udisks may not have noticed. TODO: maybe have a
-   * Block.GetSize() method instead...
-   */
-  if (ioctl (fd, BLKGETSIZE64, &data->block_size) != 0)
-    {
-      error = g_error_new (G_IO_ERROR, g_io_error_from_errno (errno), "%s", strerror (errno));
-      gdu_window_show_error (data->window, _("Error determining size of device"), error);
-      g_error_free (error);
-      create_disk_image_data_complete (data);
-      goto out;
-    }
-
-  data->block_stream = g_unix_input_stream_new (fd, TRUE);
-
-  /* Alright, time to start copying! */
-  data->cancellable = g_cancellable_new ();
-  data->buffer = g_new0 (guchar, BUFFER_SIZE);
-  data->estimator = gdu_estimator_new (data->block_size);
-  copy_more (data);
+  start_copying (data);
 
  out:
   if (fd_index != NULL)
@@ -480,7 +513,7 @@ check_overwrite (CreateDiskImageData *data)
 }
 
 static gboolean
-start_copying (CreateDiskImageData *data)
+open_device (CreateDiskImageData *data)
 {
   gboolean ret = TRUE;
   const gchar *name;
@@ -491,6 +524,7 @@ start_copying (CreateDiskImageData *data)
   folder = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (data->destination_name_fcbutton));
 
   error = NULL;
+  data->fd = -1;
   data->output_file = g_file_get_child (folder, name);
   data->output_file_stream = g_file_replace (data->output_file,
                                              NULL, /* etag */
@@ -501,7 +535,7 @@ start_copying (CreateDiskImageData *data)
   if (data->output_file_stream == NULL)
     {
       if (!(error->domain == G_IO_ERROR && error->code == G_IO_ERROR_CANCELLED))
-        gdu_window_show_error (data->window, _("Error opening file for writing"), error);
+        gdu_utils_show_error (GTK_WINDOW (data->dialog), _("Error opening file for writing"), error);
       g_error_free (error);
       g_object_unref (folder);
       create_disk_image_data_complete (data);
@@ -510,27 +544,72 @@ start_copying (CreateDiskImageData *data)
     }
   data->delete_on_free = TRUE;
 
-  udisks_block_call_open_for_backup (data->block,
-                                     g_variant_new ("a{sv}", NULL), /* options */
-                                     NULL, /* fd_list */
-                                     NULL, /* cancellable */
-                                     (GAsyncReadyCallback) open_cb,
-                                     data);
+  /* Most OSes put ACLs for logged-in users on /dev/sr* nodes (this is
+   * so CD burning tools etc. works) so see if we can open the device
+   * file ourselves. If so, great, since this avoids a polkit dialog.
+   *
+   * As opposed to udisks' OpenForBackup() we also avoid O_EXCL since
+   * the disc is read-only by its very nature. As a side-effect this
+   * allows creating a disk image of a mounted disc.
+   */
+  if (g_str_has_prefix (udisks_block_get_device (data->block), "/dev/sr"))
+    {
+      data->fd = open (udisks_block_get_device (data->block), O_RDONLY);
+    }
+
+  if (data->fd != -1)
+    {
+      start_copying (data);
+    }
+  else
+    {
+      udisks_block_call_open_for_backup (data->block,
+                                         g_variant_new ("a{sv}", NULL), /* options */
+                                         NULL, /* fd_list */
+                                         NULL, /* cancellable */
+                                         (GAsyncReadyCallback) open_cb,
+                                         data);
+    }
 
  out:
   g_clear_object (&folder);
   return ret;
 }
 
+static void
+on_dialog_response (GtkDialog     *dialog,
+                    gint           response,
+                    gpointer       user_data)
+{
+  CreateDiskImageData *data = user_data;
+  if (response == GTK_RESPONSE_OK)
+    {
+      if (check_overwrite (data))
+        {
+          gtk_label_set_markup (GTK_LABEL (data->copying_label), _("Copying data from device..."));
+
+          /* Advance to the progress page */
+          gtk_notebook_set_current_page (GTK_NOTEBOOK (data->notebook), 1);
+          gtk_widget_hide (data->start_copying_button);
+
+          open_device (data);
+        }
+    }
+  else
+    {
+      create_disk_image_data_complete (data);
+    }
+}
+
 void
 gdu_create_disk_image_dialog_show (GduWindow    *window,
                                    UDisksObject *object)
 {
   CreateDiskImageData *data;
-  gint response;
   gchar *s;
 
   data = g_new0 (CreateDiskImageData, 1);
+  data->fd = -1;
   data->ref_count = 1;
   data->window = g_object_ref (window);
   data->object = g_object_ref (object);
@@ -554,37 +633,21 @@ gdu_create_disk_image_dialog_show (GduWindow    *window,
   create_disk_image_populate (data);
   create_disk_image_update (data);
 
-  /* Make sure we attach to parent */
-  gtk_window_set_transient_for (GTK_WINDOW (data->dialog), GTK_WINDOW (window));
+  /* Translators: This is the window title for the non-modal "Create Disk Image" dialog. The %s is the device. */
+  s = g_strdup_printf (_("Create Disk Image (%s)"),
+                       udisks_block_get_preferred_device (data->block));
+  gtk_window_set_title (GTK_WINDOW (data->dialog), s);
+  g_free (s);
   gtk_dialog_set_default_response (GTK_DIALOG (data->dialog), GTK_RESPONSE_OK);
-  gtk_widget_show_all (data->dialog);
-  /* Only select the precomputed filename, not the .img extension */
+  /* Only select the precomputed filename, not the .img / .iso extension */
   gtk_editable_select_region (GTK_EDITABLE (data->destination_name_entry), 0,
                               strlen (gtk_entry_get_text (GTK_ENTRY (data->destination_name_entry))) - 4);
 
- again:
-  response = gtk_dialog_run (GTK_DIALOG (data->dialog));
-  if (response != GTK_RESPONSE_OK)
-    goto out;
+  data->response_signal_handler_id = g_signal_connect (data->dialog,
+                                                       "response",
+                                                       G_CALLBACK (on_dialog_response),
+                                                       data);
 
-  if (!check_overwrite (data))
-    goto again;
-
-  s = g_strdup_printf (_("Copying data from device <i>%s</i>..."),
-                       udisks_block_get_preferred_device (data->block));
-  gtk_label_set_markup (GTK_LABEL (data->copying_label), s);
-  g_free (s);
-
-  /* Advance to the progress page */
-  gtk_notebook_set_current_page (GTK_NOTEBOOK (data->notebook), 1);
-  gtk_widget_hide (data->start_copying_button);
-
-  if (!start_copying (data))
-    goto out;
-
-  gtk_dialog_run (GTK_DIALOG (data->dialog));
-  create_disk_image_data_complete (data);
-
- out:
-  create_disk_image_data_unref (data);
+  gtk_widget_show_all (data->dialog);
+  gtk_window_present (GTK_WINDOW (data->dialog));
 }
