@@ -1,23 +1,10 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
  *
- * Copyright (C) 2008-2011 Red Hat, Inc.
+ * Copyright (C) 2008-2012 Red Hat, Inc.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Licensed under GPL version 2 or later.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- *
- * Author: David Zeuthen <davidz@redhat.com>
+ * Author: David Zeuthen <zeuthen@gmail.com>
  */
 
 #include "config.h"
@@ -28,7 +15,6 @@
 #include "gduwindow.h"
 #include "gducrypttabdialog.h"
 #include "gduvolumegrid.h"
-#include "gduutils.h"
 
 /* ---------------------------------------------------------------------------------------------------- */
 
@@ -273,7 +259,7 @@ crypttab_dialog_present (CrypttabDialogData *data)
                   goto again;
                 }
               gtk_widget_hide (data->dialog);
-              gdu_window_show_error (data->window,
+              gdu_utils_show_error (GTK_WINDOW (data->window),
                                      _("Error removing /etc/crypttab entry"),
                                      error);
               g_error_free (error);
@@ -357,9 +343,9 @@ crypttab_dialog_present (CrypttabDialogData *data)
                       goto again;
                     }
                   gtk_widget_hide (data->dialog);
-                  gdu_window_show_error (data->window,
-                                         _("Error adding /etc/crypttab entry"),
-                                         error);
+                  gdu_utils_show_error (GTK_WINDOW (data->window),
+                                        _("Error adding /etc/crypttab entry"),
+                                        error);
                   g_error_free (error);
                   goto out;
                 }
@@ -380,9 +366,9 @@ crypttab_dialog_present (CrypttabDialogData *data)
                       goto again;
                     }
                   gtk_widget_hide (data->dialog);
-                  gdu_window_show_error (data->window,
-                                         _("Error updating /etc/crypttab entry"),
-                                         error);
+                  gdu_utils_show_error (GTK_WINDOW (data->window),
+                                        _("Error updating /etc/crypttab entry"),
+                                        error);
                   g_error_free (error);
                   goto out;
                 }
@@ -418,9 +404,9 @@ crypttab_dialog_on_get_secrets_cb (UDisksBlock       *block,
                                                           res,
                                                           &error))
     {
-      gdu_window_show_error (data->window,
-                             _("Error retrieving configuration data"),
-                             error);
+      gdu_utils_show_error (GTK_WINDOW (data->window),
+                            _("Error retrieving configuration data"),
+                            error);
       g_error_free (error);
       crypttab_dialog_free (data);
       goto out;
