@@ -1,23 +1,10 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
  *
- * Copyright (C) 2008-2011 Red Hat, Inc.
+ * Copyright (C) 2008-2012 Red Hat, Inc.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Licensed under GPL version 2 or later.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- *
- * Author: David Zeuthen <davidz@redhat.com>
+ * Author: David Zeuthen <zeuthen@gmail.com>
  */
 
 #include "config.h"
@@ -28,7 +15,6 @@
 #include "gduwindow.h"
 #include "gdupartitiondialog.h"
 #include "gduvolumegrid.h"
-#include "gduutils.h"
 
 /* ---------------------------------------------------------------------------------------------------- */
 
@@ -366,7 +352,7 @@ gdu_partition_dialog_show (GduWindow    *window,
                                                     NULL, /* GCancellable */
                                                     &error))
             {
-              gdu_window_show_error (window, _("Error setting partition type"), error);
+              gdu_utils_show_error (GTK_WINDOW (window), _("Error setting partition type"), error);
               g_error_free (error);
               goto set_out;
             }
@@ -380,7 +366,7 @@ gdu_partition_dialog_show (GduWindow    *window,
                                                     NULL, /* GCancellable */
                                                     &error))
             {
-              gdu_window_show_error (window, _("Error setting partition name"), error);
+              gdu_utils_show_error (GTK_WINDOW (window), _("Error setting partition name"), error);
               g_error_free (error);
               goto set_out;
             }
@@ -394,7 +380,7 @@ gdu_partition_dialog_show (GduWindow    *window,
                                                      NULL, /* GCancellable */
                                                      &error))
             {
-              gdu_window_show_error (window, _("Error setting partition flags"), error);
+              gdu_utils_show_error (GTK_WINDOW (window), _("Error setting partition flags"), error);
               g_error_free (error);
               goto set_out;
             }
